package cofh.thermal.expansion.block.entity.machine;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import cofh.core.util.helpers.AugmentableHelper;
import cofh.core.util.helpers.FluidHelper;
import cofh.core.util.helpers.ItemHelper;
import cofh.lib.api.StorageGroup;
import cofh.lib.api.inventory.IItemStackHolder;
import cofh.lib.fluid.FluidStorageCoFH;
import cofh.lib.inventory.ItemStorageCoFH;
import cofh.lib.util.helpers.MathHelper;
import cofh.thermal.core.config.ThermalCoreConfig;
import cofh.thermal.core.util.managers.machine.InsolatorRecipeManager;
import cofh.thermal.expansion.init.TExpTileEntities;
import cofh.thermal.expansion.inventory.container.machine.MachineInsolatorContainer;
import cofh.thermal.lib.block.entity.MachineBlockEntity;
import cofh.thermal.lib.util.recipes.IMachineInventory;
import cofh.thermal.lib.util.recipes.IThermalInventory;
import javax.annotation.Nullable;
import net.minecraft.core.BlockPos;
import net.minecraft.nbt.CompoundTag;
import net.minecraft.world.entity.player.Inventory;
import net.minecraft.world.entity.player.Player;
import net.minecraft.world.inventory.AbstractContainerMenu;
import net.minecraft.world.item.ItemStack;
import net.minecraft.world.level.block.entity.BlockEntityType;
import net.minecraft.world.level.block.state.BlockState;
import net.minecraft.world.level.material.Fluid;
import net.minecraft.world.level.material.Fluids;
import net.minecraftforge.fluids.FluidStack;

public class MachineInsolatorTile extends MachineBlockEntity {
  protected ItemStorageCoFH inputSlot;
  
  protected ItemStorageCoFH catalystSlot;
  
  protected FluidStorageCoFH waterTank;
  
  protected boolean cyclicProcessingFeature;
  
  public MachineInsolatorTile(BlockPos pos, BlockState state) {
    super((BlockEntityType)TExpTileEntities.MACHINE_INSOLATOR_TILE.get(), pos, state);
    this.inputSlot = new ItemStorageCoFH(item -> (this.filter.valid(item) && InsolatorRecipeManager.instance().validRecipe(item)));
    this.catalystSlot = new ItemStorageCoFH(item -> (item.m_41720_() instanceof cofh.thermal.core.item.SlotSealItem || InsolatorRecipeManager.instance().validCatalyst(item)));
    this.waterTank = new FluidStorageCoFH(4000, FluidHelper.IS_WATER);
    this.cyclicProcessingFeature = false;
    this.inventory.addSlot(this.inputSlot, StorageGroup.INPUT);
    this.inventory.addSlot(this.catalystSlot, StorageGroup.CATALYST);
    this.inventory.addSlots(StorageGroup.OUTPUT, 4);
    this.inventory.addSlot(this.chargeSlot, StorageGroup.INTERNAL);
    this.tankInv.addTank(this.waterTank, StorageGroup.INPUT);
    this.renderFluid = new FluidStack((Fluid)Fluids.f_76193_, 1000);
    addAugmentSlots(ThermalCoreConfig.machineAugments);
    initHandlers();
  }
  
  protected int getBaseProcessTick() {
    return InsolatorRecipeManager.instance().getBasePower();
  }
  
  protected boolean cacheRecipe() {
    this.curRecipe = InsolatorRecipeManager.instance().getRecipe((IThermalInventory)this);
    this.curCatalyst = InsolatorRecipeManager.instance().getCatalyst((IItemStackHolder)this.catalystSlot);
    if (this.curRecipe != null) {
      this.itemInputCounts = this.curRecipe.getInputItemCounts((IMachineInventory)this);
      this.fluidInputCounts = this.curRecipe.getInputFluidCounts((IMachineInventory)this);
    } 
    return (this.curRecipe != null);
  }
  
  protected void resolveInputs() {
    int primaryCount = ((Integer)this.itemInputCounts.get(0)).intValue();
    if (this.cyclicProcessingFeature) {
      boolean recycled = false;
      ItemStack input = this.inputSlot.getItemStack();
      for (ItemStorageCoFH slot : outputSlots()) {
        if (ItemHelper.itemsEqualWithTags(slot.getItemStack(), input) && slot.getCount() >= primaryCount) {
          slot.modify(-primaryCount);
          recycled = true;
          break;
        } 
      } 
      if (!recycled)
        this.inputSlot.modify(-primaryCount); 
    } else {
      this.inputSlot.modify(-primaryCount);
    } 
    int decrement = (this.itemInputCounts.size() > 1) ? ((Integer)this.itemInputCounts.get(1)).intValue() : 0;
    if (decrement > 0)
      if (this.catalystSlot.getItemStack().m_41763_()) {
        if (this.catalystSlot.getItemStack().m_41629_(decrement, MathHelper.RANDOM, null))
          this.catalystSlot.modify(-1); 
      } else {
        this.catalystSlot.modify(-decrement);
      }  
    if (!this.fluidInputCounts.isEmpty())
      this.waterTank.modify(-((Integer)this.fluidInputCounts.get(0)).intValue()); 
  }
  
  @Nullable
  public AbstractContainerMenu m_7208_(int i, Inventory inventory, Player player) {
    return (AbstractContainerMenu)new MachineInsolatorContainer(i, this.f_58857_, this.f_58858_, inventory, player);
  }
  
  protected boolean validateInputs() {
    if (!cacheRecipe())
      return false; 
    return (this.inputSlot.getCount() >= ((Integer)this.itemInputCounts.get(0)).intValue() && (this.fluidInputCounts.isEmpty() || this.waterTank.getAmount() >= ((Integer)this.fluidInputCounts.get(0)).intValue()));
  }
  
  protected void resetAttributes() {
    super.resetAttributes();
    this.cyclicProcessingFeature = false;
  }
  
  protected void setAttributesFromAugment(CompoundTag augmentData) {
    super.setAttributesFromAugment(augmentData);
    this.cyclicProcessingFeature |= (AugmentableHelper.getAttributeMod(augmentData, "CycProc") > 0.0F) ? 1 : 0;
  }
}
